@@ -1,7 +1,9 @@
 // Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
+
 package apis
 
-import v1 "github.com/stolostron/governance-policy-propagator/pkg/apis/policies/v1"
+import v1 "github.com/open-cluster-management/governance-policy-propagator/pkg/apis/policy/v1"
 
 func init() {
 	// Register the types with the Scheme so the components can map objects to GroupVersionKinds and back
