@@ -1,4 +1,5 @@
 // Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 
 package e2e
 
@@ -7,10 +8,10 @@ import (
 
 	. "github.com/onsi/ginkgo"
 	. "github.com/onsi/gomega"
-	appsv1 "github.com/stolostron/governance-policy-propagator/pkg/apis/apps/v1"
-	policiesv1 "github.com/stolostron/governance-policy-propagator/pkg/apis/policies/v1"
-	"github.com/stolostron/governance-policy-propagator/pkg/controller/common"
-	"github.com/stolostron/governance-policy-propagator/test/utils"
+	appsv1 "github.com/open-cluster-management/governance-policy-propagator/pkg/apis/apps/v1"
+	policiesv1 "github.com/open-cluster-management/governance-policy-propagator/pkg/apis/policy/v1"
+	"github.com/open-cluster-management/governance-policy-propagator/pkg/controller/common"
+	"github.com/open-cluster-management/governance-policy-propagator/test/utils"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 )
 
